sequencetools.get_indices_of_sequence_elements_equal_to_true
============================================================

.. autofunction:: abjad.tools.sequencetools.get_indices_of_sequence_elements_equal_to_true.get_indices_of_sequence_elements_equal_to_true
